/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:POINTER,BOOLEAN (../celluloid/src/../data/celluloid-marshal.lst:1) */
extern
void g_cclosure_gen_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:STRING,POINTER (../celluloid/src/../data/celluloid-marshal.lst:2) */
extern
void g_cclosure_gen_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:INT,INT (../celluloid/src/../data/celluloid-marshal.lst:3) */
extern
void g_cclosure_gen_marshal_VOID__INT_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:UINT,UINT (../celluloid/src/../data/celluloid-marshal.lst:4) */
extern
void g_cclosure_gen_marshal_VOID__UINT_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:INT64,INT64 (../celluloid/src/../data/celluloid-marshal.lst:5) */
extern
void g_cclosure_gen_marshal_VOID__INT64_INT64 (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:INT,STRING,STRING (../celluloid/src/../data/celluloid-marshal.lst:6) */
extern
void g_cclosure_gen_marshal_VOID__INT_STRING_STRING (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:INT,POINTER (../celluloid/src/../data/celluloid-marshal.lst:7) */
extern
void g_cclosure_gen_marshal_VOID__INT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN,POINTER,POINTER (../celluloid/src/../data/celluloid-marshal.lst:8) */
extern
void g_cclosure_gen_marshal_VOID__BOOLEAN_BOOLEAN_POINTER_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* VOID:UINT,UINT,UINT (../celluloid/src/../data/celluloid-marshal.lst:9) */
extern
void g_cclosure_gen_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:INT64 (../celluloid/src/../data/celluloid-marshal.lst:10) */
extern
void g_cclosure_gen_marshal_VOID__INT64 (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);


G_END_DECLS
