/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CELLULOID_MPRIS_GDBUS_H__
#define __CELLULOID_MPRIS_GDBUS_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.mpris.MediaPlayer2 */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2 (celluloid_mpris_org_mpris_media_player2_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2, celluloidmprisOrgMprisMediaPlayer2))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2, celluloidmprisOrgMprisMediaPlayer2Iface))

struct _celluloidmprisOrgMprisMediaPlayer2;
typedef struct _celluloidmprisOrgMprisMediaPlayer2 celluloidmprisOrgMprisMediaPlayer2;
typedef struct _celluloidmprisOrgMprisMediaPlayer2Iface celluloidmprisOrgMprisMediaPlayer2Iface;

struct _celluloidmprisOrgMprisMediaPlayer2Iface
{
  GTypeInterface parent_iface;


  gboolean (*handle_quit) (
    celluloidmprisOrgMprisMediaPlayer2 *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_raise) (
    celluloidmprisOrgMprisMediaPlayer2 *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_can_quit) (celluloidmprisOrgMprisMediaPlayer2 *object);

  gboolean  (*get_can_raise) (celluloidmprisOrgMprisMediaPlayer2 *object);

  gboolean  (*get_can_set_fullscreen) (celluloidmprisOrgMprisMediaPlayer2 *object);

  const gchar * (*get_desktop_entry) (celluloidmprisOrgMprisMediaPlayer2 *object);

  gboolean  (*get_fullscreen) (celluloidmprisOrgMprisMediaPlayer2 *object);

  gboolean  (*get_has_track_list) (celluloidmprisOrgMprisMediaPlayer2 *object);

  const gchar * (*get_identity) (celluloidmprisOrgMprisMediaPlayer2 *object);

  const gchar *const * (*get_supported_mime_types) (celluloidmprisOrgMprisMediaPlayer2 *object);

  const gchar *const * (*get_supported_uri_schemes) (celluloidmprisOrgMprisMediaPlayer2 *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2, g_object_unref)
#endif

GType celluloid_mpris_org_mpris_media_player2_get_type (void);

GDBusInterfaceInfo *celluloid_mpris_org_mpris_media_player2_interface_info (void);
guint celluloid_mpris_org_mpris_media_player2_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void celluloid_mpris_org_mpris_media_player2_complete_raise (
    celluloidmprisOrgMprisMediaPlayer2 *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_complete_quit (
    celluloidmprisOrgMprisMediaPlayer2 *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void celluloid_mpris_org_mpris_media_player2_call_raise (
    celluloidmprisOrgMprisMediaPlayer2 *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_call_raise_finish (
    celluloidmprisOrgMprisMediaPlayer2 *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_call_raise_sync (
    celluloidmprisOrgMprisMediaPlayer2 *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_call_quit (
    celluloidmprisOrgMprisMediaPlayer2 *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_call_quit_finish (
    celluloidmprisOrgMprisMediaPlayer2 *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_call_quit_sync (
    celluloidmprisOrgMprisMediaPlayer2 *proxy,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gboolean celluloid_mpris_org_mpris_media_player2_get_can_quit (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_can_quit (celluloidmprisOrgMprisMediaPlayer2 *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_get_fullscreen (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_fullscreen (celluloidmprisOrgMprisMediaPlayer2 *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_get_can_set_fullscreen (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_can_set_fullscreen (celluloidmprisOrgMprisMediaPlayer2 *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_get_can_raise (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_can_raise (celluloidmprisOrgMprisMediaPlayer2 *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_get_has_track_list (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_has_track_list (celluloidmprisOrgMprisMediaPlayer2 *object, gboolean value);

const gchar *celluloid_mpris_org_mpris_media_player2_get_identity (celluloidmprisOrgMprisMediaPlayer2 *object);
gchar *celluloid_mpris_org_mpris_media_player2_dup_identity (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_identity (celluloidmprisOrgMprisMediaPlayer2 *object, const gchar *value);

const gchar *celluloid_mpris_org_mpris_media_player2_get_desktop_entry (celluloidmprisOrgMprisMediaPlayer2 *object);
gchar *celluloid_mpris_org_mpris_media_player2_dup_desktop_entry (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_desktop_entry (celluloidmprisOrgMprisMediaPlayer2 *object, const gchar *value);

const gchar *const *celluloid_mpris_org_mpris_media_player2_get_supported_uri_schemes (celluloidmprisOrgMprisMediaPlayer2 *object);
gchar **celluloid_mpris_org_mpris_media_player2_dup_supported_uri_schemes (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_supported_uri_schemes (celluloidmprisOrgMprisMediaPlayer2 *object, const gchar *const *value);

const gchar *const *celluloid_mpris_org_mpris_media_player2_get_supported_mime_types (celluloidmprisOrgMprisMediaPlayer2 *object);
gchar **celluloid_mpris_org_mpris_media_player2_dup_supported_mime_types (celluloidmprisOrgMprisMediaPlayer2 *object);
void celluloid_mpris_org_mpris_media_player2_set_supported_mime_types (celluloidmprisOrgMprisMediaPlayer2 *object, const gchar *const *value);


/* ---- */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PROXY (celluloid_mpris_org_mpris_media_player2_proxy_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PROXY, celluloidmprisOrgMprisMediaPlayer2Proxy))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PROXY, celluloidmprisOrgMprisMediaPlayer2ProxyClass))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PROXY, celluloidmprisOrgMprisMediaPlayer2ProxyClass))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PROXY))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PROXY))

typedef struct _celluloidmprisOrgMprisMediaPlayer2Proxy celluloidmprisOrgMprisMediaPlayer2Proxy;
typedef struct _celluloidmprisOrgMprisMediaPlayer2ProxyClass celluloidmprisOrgMprisMediaPlayer2ProxyClass;
typedef struct _celluloidmprisOrgMprisMediaPlayer2ProxyPrivate celluloidmprisOrgMprisMediaPlayer2ProxyPrivate;

struct _celluloidmprisOrgMprisMediaPlayer2Proxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  celluloidmprisOrgMprisMediaPlayer2ProxyPrivate *priv;
};

struct _celluloidmprisOrgMprisMediaPlayer2ProxyClass
{
  GDBusProxyClass parent_class;
};

GType celluloid_mpris_org_mpris_media_player2_proxy_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2Proxy, g_object_unref)
#endif

void celluloid_mpris_org_mpris_media_player2_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
celluloidmprisOrgMprisMediaPlayer2 *celluloid_mpris_org_mpris_media_player2_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
celluloidmprisOrgMprisMediaPlayer2 *celluloid_mpris_org_mpris_media_player2_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void celluloid_mpris_org_mpris_media_player2_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
celluloidmprisOrgMprisMediaPlayer2 *celluloid_mpris_org_mpris_media_player2_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
celluloidmprisOrgMprisMediaPlayer2 *celluloid_mpris_org_mpris_media_player2_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_SKELETON (celluloid_mpris_org_mpris_media_player2_skeleton_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_SKELETON, celluloidmprisOrgMprisMediaPlayer2Skeleton))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_SKELETON, celluloidmprisOrgMprisMediaPlayer2SkeletonClass))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_SKELETON, celluloidmprisOrgMprisMediaPlayer2SkeletonClass))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_SKELETON))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_SKELETON))

typedef struct _celluloidmprisOrgMprisMediaPlayer2Skeleton celluloidmprisOrgMprisMediaPlayer2Skeleton;
typedef struct _celluloidmprisOrgMprisMediaPlayer2SkeletonClass celluloidmprisOrgMprisMediaPlayer2SkeletonClass;
typedef struct _celluloidmprisOrgMprisMediaPlayer2SkeletonPrivate celluloidmprisOrgMprisMediaPlayer2SkeletonPrivate;

struct _celluloidmprisOrgMprisMediaPlayer2Skeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  celluloidmprisOrgMprisMediaPlayer2SkeletonPrivate *priv;
};

struct _celluloidmprisOrgMprisMediaPlayer2SkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType celluloid_mpris_org_mpris_media_player2_skeleton_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2Skeleton, g_object_unref)
#endif

celluloidmprisOrgMprisMediaPlayer2 *celluloid_mpris_org_mpris_media_player2_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.mpris.MediaPlayer2.Player */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER (celluloid_mpris_org_mpris_media_player2_player_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER, celluloidmprisOrgMprisMediaPlayer2Player))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER, celluloidmprisOrgMprisMediaPlayer2PlayerIface))

struct _celluloidmprisOrgMprisMediaPlayer2Player;
typedef struct _celluloidmprisOrgMprisMediaPlayer2Player celluloidmprisOrgMprisMediaPlayer2Player;
typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerIface celluloidmprisOrgMprisMediaPlayer2PlayerIface;

struct _celluloidmprisOrgMprisMediaPlayer2PlayerIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_next) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_open_uri) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_Uri);

  gboolean (*handle_pause) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_play) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_play_pause) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_previous) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_seek) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation,
    gint64 arg_Offset);

  gboolean (*handle_set_position) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_TrackId,
    gint64 arg_Position);

  gboolean (*handle_stop) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_can_control) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gboolean  (*get_can_go_next) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gboolean  (*get_can_go_previous) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gboolean  (*get_can_pause) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gboolean  (*get_can_play) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gboolean  (*get_can_seek) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  const gchar * (*get_loop_status) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gdouble  (*get_maximum_rate) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  GVariant * (*get_metadata) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gdouble  (*get_minimum_rate) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  const gchar * (*get_playback_status) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gint64  (*get_position) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gdouble  (*get_rate) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gboolean  (*get_shuffle) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  gdouble  (*get_volume) (celluloidmprisOrgMprisMediaPlayer2Player *object);

  void (*seeked) (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    gint64 arg_Position);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2Player, g_object_unref)
#endif

GType celluloid_mpris_org_mpris_media_player2_player_get_type (void);

GDBusInterfaceInfo *celluloid_mpris_org_mpris_media_player2_player_interface_info (void);
guint celluloid_mpris_org_mpris_media_player2_player_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void celluloid_mpris_org_mpris_media_player2_player_complete_next (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_previous (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_pause (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_play_pause (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_stop (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_play (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_seek (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_set_position (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_player_complete_open_uri (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void celluloid_mpris_org_mpris_media_player2_player_emit_seeked (
    celluloidmprisOrgMprisMediaPlayer2Player *object,
    gint64 arg_Position);



/* D-Bus method calls: */
void celluloid_mpris_org_mpris_media_player2_player_call_next (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_next_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_next_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_previous (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_previous_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_previous_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_pause (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_pause_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_pause_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_play_pause (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_play_pause_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_play_pause_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_stop (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_stop_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_stop_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_play (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_play_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_play_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_seek (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    gint64 arg_Offset,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_seek_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_seek_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    gint64 arg_Offset,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_set_position (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    const gchar *arg_TrackId,
    gint64 arg_Position,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_set_position_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_set_position_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    const gchar *arg_TrackId,
    gint64 arg_Position,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_player_call_open_uri (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    const gchar *arg_Uri,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_open_uri_finish (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_player_call_open_uri_sync (
    celluloidmprisOrgMprisMediaPlayer2Player *proxy,
    const gchar *arg_Uri,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *celluloid_mpris_org_mpris_media_player2_player_get_playback_status (celluloidmprisOrgMprisMediaPlayer2Player *object);
gchar *celluloid_mpris_org_mpris_media_player2_player_dup_playback_status (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_playback_status (celluloidmprisOrgMprisMediaPlayer2Player *object, const gchar *value);

const gchar *celluloid_mpris_org_mpris_media_player2_player_get_loop_status (celluloidmprisOrgMprisMediaPlayer2Player *object);
gchar *celluloid_mpris_org_mpris_media_player2_player_dup_loop_status (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_loop_status (celluloidmprisOrgMprisMediaPlayer2Player *object, const gchar *value);

gdouble celluloid_mpris_org_mpris_media_player2_player_get_rate (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_rate (celluloidmprisOrgMprisMediaPlayer2Player *object, gdouble value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_shuffle (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_shuffle (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);

GVariant *celluloid_mpris_org_mpris_media_player2_player_get_metadata (celluloidmprisOrgMprisMediaPlayer2Player *object);
GVariant *celluloid_mpris_org_mpris_media_player2_player_dup_metadata (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_metadata (celluloidmprisOrgMprisMediaPlayer2Player *object, GVariant *value);

gdouble celluloid_mpris_org_mpris_media_player2_player_get_volume (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_volume (celluloidmprisOrgMprisMediaPlayer2Player *object, gdouble value);

gint64 celluloid_mpris_org_mpris_media_player2_player_get_position (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_position (celluloidmprisOrgMprisMediaPlayer2Player *object, gint64 value);

gdouble celluloid_mpris_org_mpris_media_player2_player_get_minimum_rate (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_minimum_rate (celluloidmprisOrgMprisMediaPlayer2Player *object, gdouble value);

gdouble celluloid_mpris_org_mpris_media_player2_player_get_maximum_rate (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_maximum_rate (celluloidmprisOrgMprisMediaPlayer2Player *object, gdouble value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_can_go_next (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_can_go_next (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_can_go_previous (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_can_go_previous (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_can_play (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_can_play (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_can_pause (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_can_pause (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_can_seek (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_can_seek (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);

gboolean celluloid_mpris_org_mpris_media_player2_player_get_can_control (celluloidmprisOrgMprisMediaPlayer2Player *object);
void celluloid_mpris_org_mpris_media_player2_player_set_can_control (celluloidmprisOrgMprisMediaPlayer2Player *object, gboolean value);


/* ---- */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY (celluloid_mpris_org_mpris_media_player2_player_proxy_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY, celluloidmprisOrgMprisMediaPlayer2PlayerProxy))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY, celluloidmprisOrgMprisMediaPlayer2PlayerProxyClass))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY, celluloidmprisOrgMprisMediaPlayer2PlayerProxyClass))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_PROXY))

typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerProxy celluloidmprisOrgMprisMediaPlayer2PlayerProxy;
typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerProxyClass celluloidmprisOrgMprisMediaPlayer2PlayerProxyClass;
typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerProxyPrivate celluloidmprisOrgMprisMediaPlayer2PlayerProxyPrivate;

struct _celluloidmprisOrgMprisMediaPlayer2PlayerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  celluloidmprisOrgMprisMediaPlayer2PlayerProxyPrivate *priv;
};

struct _celluloidmprisOrgMprisMediaPlayer2PlayerProxyClass
{
  GDBusProxyClass parent_class;
};

GType celluloid_mpris_org_mpris_media_player2_player_proxy_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2PlayerProxy, g_object_unref)
#endif

void celluloid_mpris_org_mpris_media_player2_player_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
celluloidmprisOrgMprisMediaPlayer2Player *celluloid_mpris_org_mpris_media_player2_player_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
celluloidmprisOrgMprisMediaPlayer2Player *celluloid_mpris_org_mpris_media_player2_player_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void celluloid_mpris_org_mpris_media_player2_player_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
celluloidmprisOrgMprisMediaPlayer2Player *celluloid_mpris_org_mpris_media_player2_player_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
celluloidmprisOrgMprisMediaPlayer2Player *celluloid_mpris_org_mpris_media_player2_player_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON (celluloid_mpris_org_mpris_media_player2_player_skeleton_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON, celluloidmprisOrgMprisMediaPlayer2PlayerSkeleton))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON, celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonClass))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON, celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonClass))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_PLAYER_SKELETON))

typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerSkeleton celluloidmprisOrgMprisMediaPlayer2PlayerSkeleton;
typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonClass celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonClass;
typedef struct _celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonPrivate celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonPrivate;

struct _celluloidmprisOrgMprisMediaPlayer2PlayerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonPrivate *priv;
};

struct _celluloidmprisOrgMprisMediaPlayer2PlayerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType celluloid_mpris_org_mpris_media_player2_player_skeleton_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2PlayerSkeleton, g_object_unref)
#endif

celluloidmprisOrgMprisMediaPlayer2Player *celluloid_mpris_org_mpris_media_player2_player_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.mpris.MediaPlayer2.TrackList */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST (celluloid_mpris_org_mpris_media_player2_track_list_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST, celluloidmprisOrgMprisMediaPlayer2TrackList))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST, celluloidmprisOrgMprisMediaPlayer2TrackListIface))

struct _celluloidmprisOrgMprisMediaPlayer2TrackList;
typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackList celluloidmprisOrgMprisMediaPlayer2TrackList;
typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListIface celluloidmprisOrgMprisMediaPlayer2TrackListIface;

struct _celluloidmprisOrgMprisMediaPlayer2TrackListIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_add_track) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_Uri,
    const gchar *arg_AfterTrack,
    gboolean arg_SetAsCurrent);

  gboolean (*handle_get_tracks_metadata) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *arg_TrackIds);

  gboolean (*handle_go_to) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_TrackId);

  gboolean (*handle_remove_track) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_TrackId);

  gboolean  (*get_can_edit_tracks) (celluloidmprisOrgMprisMediaPlayer2TrackList *object);

  const gchar *const * (*get_tracks) (celluloidmprisOrgMprisMediaPlayer2TrackList *object);

  void (*track_added) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GVariant *arg_Metadata,
    const gchar *arg_AfterTrack);

  void (*track_list_replaced) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    const gchar *const *arg_Tracks,
    const gchar *arg_CurrentTrack);

  void (*track_metadata_changed) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    const gchar *arg_TrackId,
    GVariant *arg_Metadata);

  void (*track_removed) (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    const gchar *arg_TrackId);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2TrackList, g_object_unref)
#endif

GType celluloid_mpris_org_mpris_media_player2_track_list_get_type (void);

GDBusInterfaceInfo *celluloid_mpris_org_mpris_media_player2_track_list_interface_info (void);
guint celluloid_mpris_org_mpris_media_player2_track_list_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void celluloid_mpris_org_mpris_media_player2_track_list_complete_get_tracks_metadata (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation,
    GVariant *Metadata);

void celluloid_mpris_org_mpris_media_player2_track_list_complete_add_track (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_track_list_complete_remove_track (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation);

void celluloid_mpris_org_mpris_media_player2_track_list_complete_go_to (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void celluloid_mpris_org_mpris_media_player2_track_list_emit_track_list_replaced (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    const gchar *const *arg_Tracks,
    const gchar *arg_CurrentTrack);

void celluloid_mpris_org_mpris_media_player2_track_list_emit_track_added (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    GVariant *arg_Metadata,
    const gchar *arg_AfterTrack);

void celluloid_mpris_org_mpris_media_player2_track_list_emit_track_removed (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    const gchar *arg_TrackId);

void celluloid_mpris_org_mpris_media_player2_track_list_emit_track_metadata_changed (
    celluloidmprisOrgMprisMediaPlayer2TrackList *object,
    const gchar *arg_TrackId,
    GVariant *arg_Metadata);



/* D-Bus method calls: */
void celluloid_mpris_org_mpris_media_player2_track_list_call_get_tracks_metadata (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *const *arg_TrackIds,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_get_tracks_metadata_finish (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    GVariant ** out_Metadata,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_get_tracks_metadata_sync (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *const *arg_TrackIds,
    GVariant ** out_Metadata,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_track_list_call_add_track (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *arg_Uri,
    const gchar *arg_AfterTrack,
    gboolean arg_SetAsCurrent,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_add_track_finish (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_add_track_sync (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *arg_Uri,
    const gchar *arg_AfterTrack,
    gboolean arg_SetAsCurrent,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_track_list_call_remove_track (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *arg_TrackId,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_remove_track_finish (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_remove_track_sync (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *arg_TrackId,
    GCancellable *cancellable,
    GError **error);

void celluloid_mpris_org_mpris_media_player2_track_list_call_go_to (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *arg_TrackId,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_go_to_finish (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    GAsyncResult *res,
    GError **error);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_call_go_to_sync (
    celluloidmprisOrgMprisMediaPlayer2TrackList *proxy,
    const gchar *arg_TrackId,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *const *celluloid_mpris_org_mpris_media_player2_track_list_get_tracks (celluloidmprisOrgMprisMediaPlayer2TrackList *object);
gchar **celluloid_mpris_org_mpris_media_player2_track_list_dup_tracks (celluloidmprisOrgMprisMediaPlayer2TrackList *object);
void celluloid_mpris_org_mpris_media_player2_track_list_set_tracks (celluloidmprisOrgMprisMediaPlayer2TrackList *object, const gchar *const *value);

gboolean celluloid_mpris_org_mpris_media_player2_track_list_get_can_edit_tracks (celluloidmprisOrgMprisMediaPlayer2TrackList *object);
void celluloid_mpris_org_mpris_media_player2_track_list_set_can_edit_tracks (celluloidmprisOrgMprisMediaPlayer2TrackList *object, gboolean value);


/* ---- */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY (celluloid_mpris_org_mpris_media_player2_track_list_proxy_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY, celluloidmprisOrgMprisMediaPlayer2TrackListProxy))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY, celluloidmprisOrgMprisMediaPlayer2TrackListProxyClass))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY, celluloidmprisOrgMprisMediaPlayer2TrackListProxyClass))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_PROXY))

typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListProxy celluloidmprisOrgMprisMediaPlayer2TrackListProxy;
typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListProxyClass celluloidmprisOrgMprisMediaPlayer2TrackListProxyClass;
typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListProxyPrivate celluloidmprisOrgMprisMediaPlayer2TrackListProxyPrivate;

struct _celluloidmprisOrgMprisMediaPlayer2TrackListProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  celluloidmprisOrgMprisMediaPlayer2TrackListProxyPrivate *priv;
};

struct _celluloidmprisOrgMprisMediaPlayer2TrackListProxyClass
{
  GDBusProxyClass parent_class;
};

GType celluloid_mpris_org_mpris_media_player2_track_list_proxy_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2TrackListProxy, g_object_unref)
#endif

void celluloid_mpris_org_mpris_media_player2_track_list_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
celluloidmprisOrgMprisMediaPlayer2TrackList *celluloid_mpris_org_mpris_media_player2_track_list_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
celluloidmprisOrgMprisMediaPlayer2TrackList *celluloid_mpris_org_mpris_media_player2_track_list_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void celluloid_mpris_org_mpris_media_player2_track_list_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
celluloidmprisOrgMprisMediaPlayer2TrackList *celluloid_mpris_org_mpris_media_player2_track_list_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
celluloidmprisOrgMprisMediaPlayer2TrackList *celluloid_mpris_org_mpris_media_player2_track_list_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON (celluloid_mpris_org_mpris_media_player2_track_list_skeleton_get_type ())
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON, celluloidmprisOrgMprisMediaPlayer2TrackListSkeleton))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON, celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonClass))
#define CELLULOID_MPRIS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON, celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonClass))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON))
#define CELLULOID_MPRIS_IS_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CELLULOID_MPRIS_TYPE_ORG_MPRIS_MEDIA_PLAYER2_TRACK_LIST_SKELETON))

typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListSkeleton celluloidmprisOrgMprisMediaPlayer2TrackListSkeleton;
typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonClass celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonClass;
typedef struct _celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonPrivate celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonPrivate;

struct _celluloidmprisOrgMprisMediaPlayer2TrackListSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonPrivate *priv;
};

struct _celluloidmprisOrgMprisMediaPlayer2TrackListSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType celluloid_mpris_org_mpris_media_player2_track_list_skeleton_get_type (void);

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (celluloidmprisOrgMprisMediaPlayer2TrackListSkeleton, g_object_unref)
#endif

celluloidmprisOrgMprisMediaPlayer2TrackList *celluloid_mpris_org_mpris_media_player2_track_list_skeleton_new (void);


G_END_DECLS

#endif /* __CELLULOID_MPRIS_GDBUS_H__ */
